==> aidlab_sdk-0.0.7.tar.gz: android/src/main/kotlin/com/aidlab/aidlab_sdk/AidlabHandler.kt <==
package com.aidlab.aidlab_sdk

import android.os.Handler
import android.os.Looper
import com.aidlab.sdk.communication.*
import com.aidlab.sdk.internal.InternalDelegate
import com.aidlab.sdk.internal.InternalUpdateDelegate
import com.aidlab.sdk.communication.DisconnectReason
import io.flutter.Log
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.BinaryMessenger

class AidlabHandler(
        val synchronizationDelegate: AidlabSynchronizationDelegate,
        binaryMessenger: BinaryMessenger
): AidlabDelegate, InternalDelegate, InternalUpdateDelegate, AidlabFlutter.PlatformAidlab {

    private var released = false

    private var aidlabListener: AidlabFlutter.PlatformAidlabDelegate? = null
    private var internalListener: AidlabFlutter.PlatformAidlabInternalDelegate? = null
    private var updateListener: AidlabFlutter.PlatformAidlabUpdateDelegate? = null

    private var connectedAidlab: IAidlab? = null
    private var isConnected = false

    init {
        released = false
        aidlabListener = AidlabFlutter.PlatformAidlabDelegate(binaryMessenger)
        internalListener = AidlabFlutter.PlatformAidlabInternalDelegate(binaryMessenger)
        updateListener = AidlabFlutter.PlatformAidlabUpdateDelegate(binaryMessenger)
        AidlabFlutter.PlatformAidlab.setup(binaryMessenger, this)
    }
    
    fun release() {
        released = true
        connectedAidlab?.disconnect()
        aidlabListener = null
    }

    override fun disconnect() {
        connectedAidlab?.disconnect()
    }

    override fun send(arg: AidlabFlutter.SendRequest?) {
        connectedAidlab?.send(arg!!.command)
    }

    override fun setECGFiltrationMethod(arg: AidlabFlutter.EcgFiltrationRequest?) {
        connectedAidlab?.setECGFiltrationMethod(ECGFiltrationMethod.values()[arg!!.method.toInt()])
    }

    override fun startSynchronization() {
        connectedAidlab?.startSynchronization()
    }

    override fun stopSynchronization() {
        connectedAidlab?.stopSynchronization()
    }

    override fun requestForFirmwareInfo(arg: AidlabFlutter.FirmwareInfoRequest?) {
        connectedAidlab?.internalAidlab?.requestForFirmwareInfo(arg!!.url)
    }

    override fun startFirmwareUpdate(arg: AidlabFlutter.FirmwareUpdateRequest?) {
        connectedAidlab?.internalAidlab?.startFirmwareUpdate(arg!!.url, arg.updatableVersion)
    }

    override fun didConnectAidlab(aidlab: IAidlab) {
        if(released) {
            aidlab.disconnect()
            return
        }
        isConnected = true
        connectedAidlab = aidlab
        aidlab.internalAidlab.internalDelegate = this
        aidlab.internalAidlab.updateDelegate = this

        connectedAidlab?.aidlabSynchronizationDelegate = synchronizationDelegate
        aidlabListener?.didConnect(AidlabFlutter.ConnectEvent().apply {
            this.firmwareRevision = aidlab.firmwareRevision
            this.hardwareRevision = aidlab.hardwareRevision
            this.serialNumber = aidlab.serialNumber
            this.address = aidlab.address()
        }) {}
    }

    override fun didDisconnectAidlab(aidlab: IAidlab, reason: DisconnectReason) {
        isConnected = false

        connectedAidlab?.aidlabSynchronizationDelegate = null
        connectedAidlab = null
        aidlabListener?.didDisconnect(AidlabFlutter.DisconnectEvent().apply {
            this.disconnectReason = reason.value.toLong()
        }) {}
    }

    override fun didReceiveECG(aidlab: IAidlab, timestamp: Long, values: FloatArray) {
        aidlabListener?.didReceiveEcg(AidlabFlutter.EcgEvent().apply {
            this.timestamp = timestamp
            this.values = DoubleArray(values.size) { values[it].toDouble() }
        }) {}
    }

    override fun didDetectExercise(aidlab: IAidlab, exercise: Exercise) {
        aidlabListener?.didDetectExercise(AidlabFlutter.ExerciseEvent().apply {
            this.exercise = exercise.value.toLong()
        }) {}
    }

    override fun didReceiveAccelerometer(aidlab: IAidlab, timestamp: Long, ax: Float, ay: Float, az: Float) {
        aidlabListener?.didReceiveAccelerometer(Utils.createVectorEvent(
                timestamp, ax, ay, az
        )) {}
    }

    override fun didReceiveActivity(aidlab: IAidlab, timestamp: Long, activity: ActivityType) {
        aidlabListener?.didReceiveActivity(AidlabFlutter.ActivityEvent().apply {
            this.timestamp = timestamp
            this.activityType = activity.value.toLong()
        }) {}
    }

    override fun didReceiveBatteryLevel(aidlab: IAidlab, stateOfCharge: Int) {
        aidlabListener?.didReceiveBatteryLevel(AidlabFlutter.BatteryLevelEvent().apply {
            this.stateOfCharge = stateOfCharge.toLong()
        }) {}
    }

    override fun didReceiveBodyPosition(aidlab: IAidlab, timestamp: Long, bodyPosition: BodyPosition) {
        aidlabListener?.didReceiveBodyPosition(AidlabFlutter.BodyPositionEvent().apply {
            this.timestamp = timestamp
            this.bodyPosition = bodyPosition.value.toLong()
        }) {}
    }

    override fun didReceiveCommand(aidlab: IAidlab) {
        Log.d("AidlabHandler", "didReceiveCommand")
        aidlabListener?.didReceiveCommand(AidlabFlutter.EmptyEvent()) {
            Log.d("AidlabHandler", "didReceiveCommand on respose")
        }
    }

    override fun didReceiveError(error: String) {
        aidlabListener?.didReceiveError(AidlabFlutter.ErrorEvent().apply {
            this.error = error
        }) {}
    }

    override fun didReceiveFirmwareInformation(updateAvailable: Boolean, updatableVersion: String) {
        Handler(Looper.getMainLooper()).post {
            internalListener?.didReceiveFirmwareInformation(AidlabFlutter.FirmwareInformationEvent().apply {
                this.updateAvailable = updateAvailable
                this.updatableVersion = updatableVersion
            }) {}
        }
    }

    override fun didReceiveGyroscope(aidlab: IAidlab, timestamp: Long, qx: Float, qy: Float, qz: Float) {
        aidlabListener?.didReceiveGyroscope(Utils.createVectorEvent(
                timestamp, qx, qz, qy
        )) {}
    }

    override fun didReceiveHeartRate(aidlab: IAidlab, timestamp: Long, heartRate: Int) {
        aidlabListener?.didReceiveHeartRate(AidlabFlutter.HeartRateEvent().apply {
            this.timestamp = timestamp
            this.heartRate = heartRate.toLong()
        }) {}
    }

    override fun didReceiveHrv(aidlab: IAidlab, timestamp: Long, hrv: Int) {
        aidlabListener?.didReceiveHrv(AidlabFlutter.HrvEvent().apply {
            this.timestamp = timestamp
            this.hrv = hrv.toLong()
        }) {}
    }

    override fun didReceiveMagnetometer(aidlab: IAidlab, timestamp: Long, mx: Float, my: Float, mz: Float) {
        aidlabListener?.didReceiveMagnetometer(Utils.createVectorEvent(
                timestamp, mx, my, mz
        )) {}
    }

    override fun didReceiveMessage(aidlab: IAidlab, process: String, message: String) {
        aidlabListener?.didReceiveMessage(AidlabFlutter.MessageEvent().apply {
            this.process = process
            this.message = message
        }) {}
    }

    override fun didReceiveOrientation(aidlab: IAidlab, timestamp: Long,
                                       roll: Float, pitch: Float, yaw: Float) {
        aidlabListener?.didReceiveOrientation(AidlabFlutter.OrientationEvent().apply {
            this.timestamp = timestamp
            this.roll = roll.toDouble()
            this.pitch = pitch.toDouble()
            this.yaw = yaw.toDouble()
        }) {}
    }

    override fun didReceivePressure(aidlab: IAidlab, timestamp: Long, values: IntArray) {
        internalListener?.didReceivePressure(AidlabFlutter.PressureEvent().apply {
            this.timestamp = timestamp
            this.values = values
        }) {}
    }

    override fun didReceiveQuaternion(aidlab: IAidlab, timestamp: Long, qw: Float, qx: Float, qy: Float, qz: Float) {
        aidlabListener?.didReceiveQuaternion(AidlabFlutter.QuaternionEvent().apply {
            this.timestamp = timestamp
            this.qw = qw.toDouble()
            this.qx = qx.toDouble()
            this.qy = qy.toDouble()
            this.qz = qz.toDouble()
        }) {}
    }

    override fun didReceiveRespiration(aidlab: IAidlab, timestamp: Long, values: FloatArray) {
        aidlabListener?.didReceiveRespiration(AidlabFlutter.RespirationEvent().apply {
            this.timestamp = timestamp
            this.values = DoubleArray(values.size) {index -> values[index].toDouble()}
        }) {}
    }

    override fun didReceiveRespirationRate(aidlab: IAidlab, timestamp: Long, value: Int) {
        aidlabListener?.didReceiveRespirationRate(AidlabFlutter.RespirationRateEvent().apply {
            this.timestamp = timestamp
            this.value = value.toLong()
        }) {}
    }

    override fun didReceiveSkinTemperature(aidlab: IAidlab, timestamp: Long, value: Float) {
        aidlabListener?.didReceiveSkinTemperature(AidlabFlutter.SkinTemperatureEvent().apply { 
            this.timestamp = timestamp
            this.value = value.toDouble()
        }) {}
    }

    override fun didReceiveSoundVolume(aidlab: IAidlab, timestamp: Long, value: Int) {
        aidlabListener?.didReceiveSoundVolume(AidlabFlutter.SoundVolumeEvent().apply {
            this.timestamp = timestamp
            this.soundVolume = value.toLong()
        }) {}
    }

    override fun didReceiveSteps(aidlab: IAidlab, timestamp: Long, value: Long) {
        aidlabListener?.didReceiveSteps(AidlabFlutter.StepsEvent().apply {
            this.timestamp = timestamp
            this.value = value
        }) {}
    }

    override fun pressureWearStateDidChange(aidlab: IAidlab, state: WearState) {
        internalListener?.pressureWearStateDidChange(AidlabFlutter.PressureWearStateEvent().apply {
            this.wearState = state.value.toLong()
        }) {}
    }

    override fun wearStateDidChange(aidlab: IAidlab, wearState: WearState) { 
        aidlabListener?.wearStateDidChange(AidlabFlutter.WearStateEvent().apply { 
            this.wearState = wearState.value.toLong()
        }) {}
    }

    override fun didReceiveSoundFeatures(aidlab: IAidlab, values: FloatArray): Unit {
        aidlabListener?.didReceiveSoundFeatures(AidlabFlutter.SoundFeaturesEvent().apply {
            this.values = values.map { it.toDouble() }.toDoubleArray()
        }) {}
    }

    override fun didDetectUserEvent(timestamp: Long) {
        aidlabListener?.didDetectUserEvent(
                AidlabFlutter.UserEvent().apply { this.timestamp = timestamp }) {}
    }

    override fun didFinishUpdate() {
        updateListener?.didFinishUpdate(AidlabFlutter.EmptyEvent()) {}
    }

    override fun didReceiveUpdateError(error: UpdateError) {
        updateListener?.didReceiveUpdateError(AidlabFlutter.UpdateEvent().apply {
            this.error = error.value.toLong()
        }) {}
    }

    override fun didReceiveUpdateProgress(progress: Int) {
        updateListener?.didReceiveUpdateProgress(AidlabFlutter.UpdateProgress().apply {
            this.progress = progress.toLong()
        }) {}
    }


}

==> aidlab_sdk-0.0.15.tar.gz: android/src/main/kotlin/com/aidlab/aidlab_sdk/AidlabHandler.kt <==
package com.aidlab.aidlab_sdk

import android.os.Handler
import android.os.Looper
import com.aidlab.sdk.communication.*
import com.aidlab.sdk.internal.InternalDelegate
import com.aidlab.sdk.internal.InternalUpdateDelegate
import com.aidlab.sdk.communication.DisconnectReason
import io.flutter.Log
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.BinaryMessenger

class AidlabHandler(
    val synchronizationDelegate: AidlabSynchronizationDelegate,
    binaryMessenger: BinaryMessenger
) : AidlabDelegate, InternalDelegate, InternalUpdateDelegate, AidlabFlutter.PlatformAidlab {

    private var released = false

    private var aidlabListener: AidlabFlutter.PlatformAidlabDelegate? = null
    private var internalListener: AidlabFlutter.PlatformAidlabInternalDelegate? = null
    private var updateListener: AidlabFlutter.PlatformAidlabUpdateDelegate? = null

    private var connectedAidlab: IAidlab? = null
    private var isConnected = false

    init {
        released = false
        aidlabListener = AidlabFlutter.PlatformAidlabDelegate(binaryMessenger)
        internalListener = AidlabFlutter.PlatformAidlabInternalDelegate(binaryMessenger)
        updateListener = AidlabFlutter.PlatformAidlabUpdateDelegate(binaryMessenger)
        AidlabFlutter.PlatformAidlab.setup(binaryMessenger, this)
    }

    fun release() {
        released = true
        connectedAidlab?.disconnect()
        aidlabListener = null
    }

    override fun disconnect() {
        connectedAidlab?.disconnect()
    }

    override fun send(arg: AidlabFlutter.SendRequest?) {
        connectedAidlab?.send(arg!!.command)
    }

    override fun setECGFiltrationMethod(arg: AidlabFlutter.EcgFiltrationRequest?) {
        connectedAidlab?.setECGFiltrationMethod(ECGFiltrationMethod.values()[arg!!.method.toInt()])
    }

    override fun startSynchronization() {
        connectedAidlab?.startSynchronization()
    }

    override fun stopSynchronization() {
        connectedAidlab?.stopSynchronization()
    }

    override fun requestForFirmwareInfo(arg: AidlabFlutter.FirmwareInfoRequest?) {
        connectedAidlab?.internalAidlab?.requestForFirmwareInfo(arg!!.url)
    }

    override fun startFirmwareUpdate(arg: AidlabFlutter.FirmwareUpdateRequest?) {
        connectedAidlab?.internalAidlab?.startFirmwareUpdate(arg!!.url, arg.updatableVersion)
    }

    override fun didConnectAidlab(aidlab: IAidlab) {
        if (released) {
            aidlab.disconnect()
            return
        }
        isConnected = true
        connectedAidlab = aidlab
        aidlab.internalAidlab.internalDelegate = this
        aidlab.internalAidlab.updateDelegate = this

        connectedAidlab?.aidlabSynchronizationDelegate = synchronizationDelegate
        aidlabListener?.didConnect(AidlabFlutter.ConnectEvent().apply {
            this.firmwareRevision = aidlab.firmwareRevision
            this.hardwareRevision = aidlab.hardwareRevision
            this.serialNumber = aidlab.serialNumber
            this.address = aidlab.address()
        }) {}
    }

    override fun didDisconnectAidlab(aidlab: IAidlab, reason: DisconnectReason) {
        isConnected = false

        connectedAidlab?.aidlabSynchronizationDelegate = null
        connectedAidlab = null
        aidlabListener?.didDisconnect(AidlabFlutter.DisconnectEvent().apply {
            this.disconnectReason = reason.value.toLong()
        }) {}
    }

    override fun didReceiveECG(aidlab: IAidlab, timestamp: Long, values: FloatArray) {
        aidlabListener?.didReceiveEcg(AidlabFlutter.EcgEvent().apply {
            this.timestamp = timestamp
            this.values = DoubleArray(values.size) { values[it].toDouble() }
        }) {}
    }

    override fun didDetectExercise(aidlab: IAidlab, exercise: Exercise) {
        aidlabListener?.didDetectExercise(AidlabFlutter.ExerciseEvent().apply {
            this.exercise = exercise.value.toLong()
        }) {}
    }

    override fun didReceiveAccelerometer(
        aidlab: IAidlab,
        timestamp: Long,
        ax: Float,
        ay: Float,
        az: Float
    ) {
        aidlabListener?.didReceiveAccelerometer(
            Utils.createVectorEvent(
                timestamp, ax, ay, az
            )
        ) {}
    }

    override fun didReceiveActivity(aidlab: IAidlab, timestamp: Long, activity: ActivityType) {
        aidlabListener?.didReceiveActivity(AidlabFlutter.ActivityEvent().apply {
            this.timestamp = timestamp
            this.activityType = activity.value.toLong()
        }) {}
    }

    override fun didReceiveBatteryLevel(aidlab: IAidlab, stateOfCharge: Int) {
        aidlabListener?.didReceiveBatteryLevel(AidlabFlutter.BatteryLevelEvent().apply {
            this.stateOfCharge = stateOfCharge.toLong()
        }) {}
    }

    override fun didReceiveBodyPosition(
        aidlab: IAidlab,
        timestamp: Long,
        bodyPosition: BodyPosition
    ) {
        aidlabListener?.didReceiveBodyPosition(AidlabFlutter.BodyPositionEvent().apply {
            this.timestamp = timestamp
            this.bodyPosition = bodyPosition.value.toLong()
        }) {}
    }

    override fun didReceiveCommand(aidlab: IAidlab) {
        Log.d("AidlabHandler", "didReceiveCommand")
        aidlabListener?.didReceiveCommand(AidlabFlutter.EmptyEvent()) {
            Log.d("AidlabHandler", "didReceiveCommand on respose")
        }
    }

    override fun didReceiveError(error: String) {
        aidlabListener?.didReceiveError(AidlabFlutter.ErrorEvent().apply {
            this.error = error
        }) {}
    }

    override fun didReceiveFirmwareInformation(updateAvailable: Boolean, updatableVersion: String) {
        Handler(Looper.getMainLooper()).post {
            internalListener?.didReceiveFirmwareInformation(
                AidlabFlutter.FirmwareInformationEvent().apply {
                    this.updateAvailable = updateAvailable
                    this.updatableVersion = updatableVersion
                }) {}
        }
    }

    override fun didReceiveGyroscope(
        aidlab: IAidlab,
        timestamp: Long,
        qx: Float,
        qy: Float,
        qz: Float
    ) {
        aidlabListener?.didReceiveGyroscope(
            Utils.createVectorEvent(
                timestamp, qx, qz, qy
            )
        ) {}
    }

    override fun didReceiveHeartRate(aidlab: IAidlab, timestamp: Long, heartRate: Int) {
        aidlabListener?.didReceiveHeartRate(AidlabFlutter.HeartRateEvent().apply {
            this.timestamp = timestamp
            this.heartRate = heartRate.toLong()
        }) {}
    }

    override fun didReceiveHrv(aidlab: IAidlab, timestamp: Long, hrv: Int) {
        aidlabListener?.didReceiveHrv(AidlabFlutter.HrvEvent().apply {
            this.timestamp = timestamp
            this.hrv = hrv.toLong()
        }) {}
    }

    override fun didReceiveMagnetometer(
        aidlab: IAidlab,
        timestamp: Long,
        mx: Float,
        my: Float,
        mz: Float
    ) {
        aidlabListener?.didReceiveMagnetometer(
            Utils.createVectorEvent(
                timestamp, mx, my, mz
            )
        ) {}
    }

    override fun didReceiveMessage(aidlab: IAidlab, process: String, message: String) {
        aidlabListener?.didReceiveMessage(AidlabFlutter.MessageEvent().apply {
            this.process = process
            this.message = message
        }) {}
    }

    override fun didReceiveOrientation(
        aidlab: IAidlab, timestamp: Long,
        roll: Float, pitch: Float, yaw: Float
    ) {
        aidlabListener?.didReceiveOrientation(AidlabFlutter.OrientationEvent().apply {
            this.timestamp = timestamp
            this.roll = roll.toDouble()
            this.pitch = pitch.toDouble()
            this.yaw = yaw.toDouble()
        }) {}
    }

    override fun didReceivePressure(aidlab: IAidlab, timestamp: Long, values: IntArray) {
        internalListener?.didReceivePressure(AidlabFlutter.PressureEvent().apply {
            this.timestamp = timestamp
            this.values = values
        }) {}
    }

    override fun didReceiveQuaternion(
        aidlab: IAidlab,
        timestamp: Long,
        qw: Float,
        qx: Float,
        qy: Float,
        qz: Float
    ) {
        aidlabListener?.didReceiveQuaternion(AidlabFlutter.QuaternionEvent().apply {
            this.timestamp = timestamp
            this.qw = qw.toDouble()
            this.qx = qx.toDouble()
            this.qy = qy.toDouble()
            this.qz = qz.toDouble()
        }) {}
    }

    override fun didReceiveRespiration(aidlab: IAidlab, timestamp: Long, values: FloatArray) {
        aidlabListener?.didReceiveRespiration(AidlabFlutter.RespirationEvent().apply {
            this.timestamp = timestamp
            this.values = DoubleArray(values.size) { index -> values[index].toDouble() }
        }) {}
    }

    override fun didReceiveRespirationRate(aidlab: IAidlab, timestamp: Long, value: Int) {
        aidlabListener?.didReceiveRespirationRate(AidlabFlutter.RespirationRateEvent().apply {
            this.timestamp = timestamp
            this.value = value.toLong()
        }) {}
    }

    override fun didReceiveSkinTemperature(aidlab: IAidlab, timestamp: Long, value: Float) {
        aidlabListener?.didReceiveSkinTemperature(AidlabFlutter.SkinTemperatureEvent().apply {
            this.timestamp = timestamp
            this.value = value.toDouble()
        }) {}
    }

    override fun didReceiveSoundVolume(aidlab: IAidlab, timestamp: Long, value: Int) {
        aidlabListener?.didReceiveSoundVolume(AidlabFlutter.SoundVolumeEvent().apply {
            this.timestamp = timestamp
            this.soundVolume = value.toLong()
        }) {}
    }

    override fun didReceiveSteps(aidlab: IAidlab, timestamp: Long, value: Long) {
        aidlabListener?.didReceiveSteps(AidlabFlutter.StepsEvent().apply {
            this.timestamp = timestamp
            this.value = value
        }) {}
    }

    override fun pressureWearStateDidChange(aidlab: IAidlab, state: WearState) {
        internalListener?.pressureWearStateDidChange(AidlabFlutter.PressureWearStateEvent().apply {
            this.wearState = state.value.toLong()
        }) {}
    }

    override fun wearStateDidChange(aidlab: IAidlab, wearState: WearState) {
        aidlabListener?.wearStateDidChange(AidlabFlutter.WearStateEvent().apply {
            this.wearState = wearState.value.toLong()
        }) {}
    }

    override fun didReceiveSoundFeatures(aidlab: IAidlab, values: FloatArray): Unit {
        aidlabListener?.didReceiveSoundFeatures(AidlabFlutter.SoundFeaturesEvent().apply {
            this.values = values.map { it.toDouble() }.toDoubleArray()
        }) {}
    }

    override fun didDetectUserEvent(timestamp: Long) {
        aidlabListener?.didDetectUserEvent(
            AidlabFlutter.UserEvent().apply { this.timestamp = timestamp }) {}
    }

    override fun didFinishUpdate() {
        updateListener?.didFinishUpdate(AidlabFlutter.EmptyEvent()) {}
    }

    override fun didReceiveUpdateError(error: UpdateError) {
        // Change to the UI thread. Other callback are on the UI thread by default
        Handler(Looper.getMainLooper()).post {
            updateListener?.didReceiveUpdateError(AidlabFlutter.UpdateEvent().apply {
                this.error = error.value.toLong()
            }) {}
        }
    }

    override fun didReceiveUpdateProgress(progress: Int) {
        updateListener?.didReceiveUpdateProgress(AidlabFlutter.UpdateProgress().apply {
            this.progress = progress.toLong()
        }) {}
    }


}
